@@ -17,37 +17,6 @@ from . import tasking
 from .consoling import getConsole
 console = getConsole()
 
-#utility functions
-def resolveFramer(framer, who=''):
-    """ Returns resolved framer instance from framer
-        framer may be name of framer or instance
-        who is optinal name of object owning the link such as framer or frame
-        Framer.Names registry must be setup
-    """
-    if not isinstance(framer, Framer): # not instance so name
-        if framer not in Framer.Names: 
-            raise excepting.ResolveError("ResolveError: Bad framer link name", framer, who)
-        framer = Framer.Names[framer]
-
-    return framer
-
-ResolveFramer = resolveFramer
-
-def resolveFrame(frame, who=''):
-    """ Returns resolved frame instance from frame
-            frame may be name of frame or instance
-    
-            Frame.Names registry must be setup
-        """    
-    if not isinstance(frame, Frame): # not instance so name
-        if frame not in Frame.Names: 
-            raise excepting.ResolveError("ResolveError: Bad frame link name", frame, who)
-        frame = Frame.Names[frame] #replace frame name with frame
-    
-    return frame
-
-ResolveFrame = resolveFrame
-
 #Class definitions
 
 class Framer(tasking.Tasker):
@@ -1219,38 +1188,50 @@ class Frame(registering.StoriedRegistry):
     def addBeact(self, act):
         """        """
         self.beacts.append(act)
+        act.frame = self.name #resolve later
+        act.context = ActionContextNames[BENTER]
 
     def addEnact(self, act):
         """         """
         self.enacts.append(act)
+        act.frame = self.name #resolve later
+        act.context = ActionContextNames[ENTER]        
 
     def insertEnact(self, act, index=0):
         """         """
-        self.enacts.insert(index, act)    
+        self.enacts.insert(index, act)
+        act.frame = self.name #resolve later
+        act.context = ActionContextNames[ENTER]         
 
     def addRenact(self, act):
         """         """
         self.renacts.append(act)
+        act.frame = self.name #resolve later
+        act.context = ActionContextNames[RENTER]         
 
     def addReact(self, act):
         """         """
         self.reacts.append(act)
+        act.frame = self.name #resolve later
+        act.context = ActionContextNames[RECUR]         
 
     def addPreact(self, act):
         """         """
         self.preacts.append(act)
-
-    def addTransact(self, act):
-        """         """
-        self.transacts.append(act)
+        act.frame = self.name #resolve later
+        act.context = ActionContextNames[PRECUR]         
 
     def addExact(self, act):
         """         """
         self.exacts.append(act)
-
+        act.frame = self.name #resolve later
+        act.context = ActionContextNames[EXIT]         
+        
     def addRexact(self, act):
         """         """
         self.rexacts.append(act)
+        act.frame = self.name #resolve later
+        act.context = ActionContextNames[REXIT]         
 
     def addAux(self, aux):
         """         """
@@ -1280,7 +1261,37 @@ class Frame(registering.StoriedRegistry):
 
         return True #needed since builder uses it
 
+    
+#utility functions
+def resolveFramer(framer, who=''):
+    """ Returns resolved framer instance from framer
+        framer may be name of framer or instance
+        who is optinal name of object owning the link such as framer or frame
+        Framer.Names registry must be setup
+    """
+    if not isinstance(framer, Framer): # not instance so name
+        if framer not in Framer.Names: 
+            raise excepting.ResolveError("ResolveError: Bad framer link name", framer, who)
+        framer = Framer.Names[framer]
 
+    return framer
+
+ResolveFramer = resolveFramer
+
+def resolveFrame(frame, who=''):
+    """ Returns resolved frame instance from frame
+            frame may be name of frame or instance
+    
+            Frame.Names registry must be setup
+        """    
+    if not isinstance(frame, Frame): # not instance so name
+        if frame not in Frame.Names: 
+            raise excepting.ResolveError("ResolveError: Bad frame link name", frame, who)
+        frame = Frame.Names[frame] #replace frame name with frame
+    
+    return frame
+
+ResolveFrame = resolveFrame
 
 def TestFrame():
     """Module Common self test
@@ -1346,7 +1357,7 @@ def TestFrame():
         a = Act(action = need, act = need.checkDepth, parms = dict(depth = 4.0))
         t.needs.append(a)
         t.far = f5
-        f2.transacts.append(t)
+        f2.preacts.append(t)
 
         a = Act(action = deed, act = deed.doDepth, parms = dict(depth = 1.0))
         f2.preacts.append(a)
@@ -1355,7 +1366,7 @@ def TestFrame():
         a = Act(action = need, act = need.checkDepth, parms = dict(depth = 1.5))
         t.needs.append(a)
         t.far = f4
-        f5.transacts.append(t)
+        f5.preacts.append(t)
 
         #setup auxiliary framework
         f6 = Frame()
