@@ -50,11 +50,39 @@ class Want(acting.Actor):
         if 'preface' not in kw:
             kw['preface'] = 'Fiat'
 
-        super(Want,self).__init__(**kw)  
+        super(Want,self).__init__(**kw)
+
+    def cloneParms(self, parms, clones, **kw):
+        """ Returns parms fixed up for framing cloning. This includes:
+            Reverting any Frame links to name strings,
+            Reverting non cloned Framer links into name strings
+            Replacing any cloned framer links with the cloned name strings from clones
+            Replacing any parms that are acts with clones.
+            
+            clones is dict whose items keys are original framer names
+            and values are duples of (original,clone) framer references
+        """
+        parms = super(StatusNeed,self).cloneParms(parms, clones, **kw)
+        taskers = parms.get('taskers')
+        links = []      
+        for tasker in taskers:
+            if isinstance(tasker, tasking.Tasker):
+                if tasker.name in clones: # replace name with clone.name
+                    links.append(clones[tasker.name][1].name)
+                else:
+                    links.append(tasker.name) # revert to name
+            elif tasker in clones: # replace name with clone.name
+                links.append(clones[tasker][1].name)
+            else:
+                links.append(tasker)
+        
+        parms['taskers'] = links
+        
+        return parms    
 
     def resolveLinks(self, taskers, **kw):
-        """Resolves value (tasker) link that is passed in as parm
-           resolved link is passed back to act to store in parms
+        """Resolves value taskers list of links that is passed in as parm
+           resolved links are passed back to act to store in parms
            since tasker may not be current framer at build time
         """
         parms = {}
